@@ -115,38 +115,42 @@ def _create_afl_afltables_team_model(
     return TeamModel(
         identifier=identifier,
         name=name,
-        players=[  # pyright: ignore
-            create_afl_afltables_player_model(
-                player_url=player_url,
-                jersey=jersey,
-                kicks=kicks,
-                session=session,
-                name=name,
-                marks=marks,
-                handballs=handballs,
-                disposals=disposals,
-                goals=goals,
-                behinds=behinds,
-                hit_outs=hit_outs,
-                tackles=tackles,
-                rebounds=rebounds,
-                insides=insides,
-                clearances=clearances,
-                clangers=clangers,
-                free_kicks_for=free_kicks_for,
-                free_kicks_against=free_kicks_against,
-                brownlow_votes=brownlow_votes,
-                contested_possessions=contested_possessions,
-                uncontested_possessions=uncontested_possessions,
-                contested_marks=contested_marks,
-                marks_inside=marks_inside,
-                one_percenters=one_percenters,
-                bounces=bounces,
-                goal_assists=goal_assists,
-                percentage_played=percentage_played,
-                dt=dt,
-            )
-            for player_url, jersey, kicks, name, marks, handballs, disposals, goals, behinds, hit_outs, tackles, rebounds, insides, clearances, clangers, free_kicks_for, free_kicks_against, brownlow_votes, contested_possessions, uncontested_possessions, contested_marks, marks_inside, one_percenters, bounces, goal_assists, percentage_played in players
+        players=[
+            x
+            for x in [  # pyright: ignore
+                create_afl_afltables_player_model(
+                    player_url=player_url,
+                    jersey=jersey,
+                    kicks=kicks,
+                    session=session,
+                    name=name,
+                    marks=marks,
+                    handballs=handballs,
+                    disposals=disposals,
+                    goals=goals,
+                    behinds=behinds,
+                    hit_outs=hit_outs,
+                    tackles=tackles,
+                    rebounds=rebounds,
+                    insides=insides,
+                    clearances=clearances,
+                    clangers=clangers,
+                    free_kicks_for=free_kicks_for,
+                    free_kicks_against=free_kicks_against,
+                    brownlow_votes=brownlow_votes,
+                    contested_possessions=contested_possessions,
+                    uncontested_possessions=uncontested_possessions,
+                    contested_marks=contested_marks,
+                    marks_inside=marks_inside,
+                    one_percenters=one_percenters,
+                    bounces=bounces,
+                    goal_assists=goal_assists,
+                    percentage_played=percentage_played,
+                    dt=dt,
+                )
+                for player_url, jersey, kicks, name, marks, handballs, disposals, goals, behinds, hit_outs, tackles, rebounds, insides, clearances, clangers, free_kicks_for, free_kicks_against, brownlow_votes, contested_possessions, uncontested_possessions, contested_marks, marks_inside, one_percenters, bounces, goal_assists, percentage_played in players
+            ]
+            if x is not None
         ],
         odds=[],
         points=points,
