@@ -3,7 +3,7 @@
 import datetime
 from typing import Literal
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 from .field_type import TYPE_KEY, FieldType
 
@@ -16,6 +16,13 @@ NEWS_SOURCE_COLUMN: Literal["source"] = "source"
 class NewsModel(BaseModel):
     """The serialisable news class."""
 
+    model_config = ConfigDict(
+        validate_assignment=False,
+        revalidate_instances="never",
+        extra="ignore",
+        from_attributes=False,
+    )
+
     title: str = Field(
         ..., json_schema_extra={TYPE_KEY: FieldType.TEXT}, alias=NEWS_TITLE_COLUMN
     )
